@@ -1,27 +1,12 @@
 #!/usr/bin/perl
 
-# Copyright [2015-2018] EMBL-European Bioinformatics Institute
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 use strict;
 use File::Temp 'tempdir';
 use Cwd;
 use File::Path qw(make_path);
 use Getopt::Long;
 
-my $htslib_version = "1.5";
-my $version = get_version();
+my $htslib_version = "1.3.1";
 
 my $help = "INSTALL.pl [-h|--help] [--prefix=filepath] [--static] [~/prefix/path]\n";
 $help .= "--help (-h)  - this help message\n";
@@ -39,7 +24,6 @@ my $prefix_path;
 $prefix_path = $opts->{'prefix'} if(exists($opts->{'prefix'}) && defined($opts->{'prefix'}));
 $htslib_version = $opts->{'htslib_version'} if($opts->{'htslib_version'}) ;
 
-my ($version_major,$version_minor,$version_revision) = split /\./, $htslib_version ;
 
 
 # STEP 0: various dependencies
@@ -66,35 +50,13 @@ On Debian/Ubuntu systems you can do this with the command:
   apt-get install build-essential
 END
 
-# The following libraries are version number dependant for HTSlib
-if( $version_major >= 2 || ($version_major==1 && $version_minor>=5) )
-{
--e '/usr/include/lzma.h' or die <<END;
-lzma.h library header not found in /usr/include. Please install it and try again.
-On Debian/Ubuntu systems you can do this with the command:
-
-  apt-get install liblzma-dev
-END
-
--e '/usr/include/bzlib.h' or die <<END;
-zlib.h library header not found in /usr/include. Please install it and try again.
-On Debian/Ubuntu systems you can do this with the command:
-
-  apt-get install libbz2-dev
-END
-}
-else
-{
 -e '/usr/include/zlib.h' or die <<END;
 zlib.h library header not found in /usr/include. Please install it and try again.
 On Debian/Ubuntu systems you can do this with the command:
 
   apt-get install zlib1g-dev
 END
-
     ;
-}
-
 
 eval "require Bio::SeqFeature::Lite" or die <<END;
 BioPerl does not seem to be installed. Please install it and try again.
@@ -118,31 +80,23 @@ info("Checking out HTSlib v".$htslib_version);
 chdir $install_dir;
 my $htslib_archive = $htslib_version.".zip" ;
 my $htslib_archive_url = "https://github.com/samtools/htslib/archive/".$htslib_version.".zip" ;
-system "wget -O " . $htslib_archive . " " .$htslib_archive_url  ;
-if ( $? == -1 )
-{
-  die "HTSlib fetch command failed: $!\n";
-}
+system "wget ".$htslib_archive_url  ;
 -f './'.$htslib_archive or die "Could not fetch HTSlib archive ".$htslib_archive_url ;
 system "unzip ".$htslib_archive ;
 system "mv htslib-$htslib_version htslib" ;
 -d './htslib' or die "Unzip seems to have failed. Could not find $install_dir/htslib directory";
 
 
-# STEP 3: Download Bio-DB-HTS
-info("Fetching version $version of Bio-DB-HTS from GitHub");
+# STEP 3: Download Bio-HTS
+info("Fetching latest version of Bio-HTS from GitHub");
 chdir $install_dir;
-my $biodbhts_archive = "$version.zip" ;
-my $biodbhts_archive_url = "https://github.com/Ensembl/Bio-DB-HTS/archive/$version.zip" ;
-system "wget -O " . $biodbhts_archive . " " .$biodbhts_archive_url  ;
-if ( $? == -1 )
-{
-  die "Bio-DB-HTS fetch command failed: $!\n";
-}
--f './'.$biodbhts_archive or die "Could not fetch Bio::DB::HTS archive ".$biodbhts_archive_url ;
+my $biodbhts_archive = "master.zip" ;
+my $biodbhts_archive_url = "https://github.com/Ensembl/Bio-HTS/archive/master.zip" ;
+system "wget ".$biodbhts_archive_url  ;
+-f './'.$htslib_archive or die "Could not fetch Bio::DB::HTS archive ".$biodbhts_archive_url ;
 system "unzip ".$biodbhts_archive ;
-system "mv Bio-DB-HTS-$version Bio-DB-HTS" ;
--d './Bio-DB-HTS' or die "Unzip seems to have failed. Could not find $install_dir/Bio-DB-HTS directory";
+system "mv Bio-HTS-master Bio-HTS" ;
+-d './Bio-HTS' or die "Unzip seems to have failed. Could not find $install_dir/Bio-HTS directory";
 
 
 # Step 4: Build libhts.a
@@ -175,9 +129,9 @@ if($opts->{'static'}){
 }
 -e 'libhts.a' or die "Compile didn't complete. No libhts.a library file found";
 
-# Step 5: Build Bio::DB::HTS
-info("Building Bio::DB::HTS");
-chdir "$install_dir/Bio-DB-HTS";
+# Step 5: Build Bio::DB::HTSlib
+info("Building Bio::DB::HTSlib");
+chdir "$install_dir/Bio-HTS";
 my $cmd;
 if(defined $prefix_path) {
   if(!$opts->{'static'}){
@@ -212,7 +166,7 @@ if($opts->{'static'}){
 }
 
 # Step 7: Yay!
-info("Bio::DB::HTS v$version is now installed.");
+info("Bio::DB::HTS is now installed.");
 chdir '/';
 
 exit 0;
@@ -277,16 +231,3 @@ sub prefix_install {
   }
   return $prefix_path;
 }
-
-sub get_version {
-  use FindBin '$Bin';
-  my $version = `grep -m 1 "HTS::VERSION" $Bin/lib/Bio/DB/HTS.pm`;
-  $version =~ /(\d+?\.\d+?)\D/;
-  $version = $1;
-
-  use Carp;
-  croak "Couldn't get a meaningful library version: $version"
-    unless $version =~ /\d+?\.\d+?/;
-
-  return $version;
-}
