@@ -1,7 +1,7 @@
 
 =head1 LICENSE
 
-Copyright [2015-2018] EMBL-European Bioinformatics Institute
+Copyright [1999-2016] EMBL-European Bioinformatics Institute
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -21,80 +21,40 @@ package Bio::DB::HTS::Tabix;
 
 use Bio::DB::HTS;
 use Bio::DB::HTS::Tabix::Iterator;
-$Bio::DB::HTS::Tabix::VERSION = '2.11';
+$Bio::DB::HTS::Tabix::VERSION = '2.2';
 use strict;
 use warnings;
 
 use Scalar::Util qw/reftype/;
-use File::Spec;
-use Cwd;
 
 sub new {
   my $class         = shift;
   my (%args) = @_;
   my $filename = $args{filename};
   my $warnings = $args{warnings};
-  my $use_tmp_dir = $args{use_tmp_dir};
 
   # filename checks
   die "Tabix region lookup requires a gzipped, tabixed bedfile" unless $filename =~ /gz$/;
-  my $pdir    = getcwd;
-  my $tmpdir = File::Spec->tmpdir;
-
-  #change to the tmp dir to allow the C library to download remote index files
-  if( Bio::DB::HTSfile->is_remote($filename) && ( !defined $use_tmp_dir || $use_tmp_dir != 0) )
-  {
-    chdir($tmpdir);
-  }
 
   my $htsfile = Bio::DB::HTSfile->open($filename);
   my $tabix_index = tbx_open($filename);
-  # use Data::Dumper; print $tabix_index; die;
   die "Couldn't find index for file " . $filename unless $tabix_index;
   my $header = tbx_header($htsfile, $tabix_index);
-  if( $header ) {
+  if( $header )
+  {
     $header = join "\n", @{ $header } ;
-  } else {
-    $header = '';
   }
-  
-  chdir($pdir);
 
   my $self = bless {
                     _htsfile => $htsfile,
                     _filename => $filename,
                     _tabix_index => $tabix_index,
-                    _header => $header,
+                    _header=> $header,
                    }, ref $class || $class;
 
   return $self;
 }
 
-sub query_full {
-  my ($self, $chr, $start, $end) = @_;
-  my $region = $chr;
-  $region .= ':'; #trailing ':' required for odd chr containing ':'
-  if(defined $start) {
-    $region .= $start;
-    $region .= '-'.$end if(defined $end);
-  }
-  
-  my $iter = tbx_query( $self->{_tabix_index}, $region );
-  unless ( $iter ) {
-    # this likely means the chromosome wasn't found in the tabix index, or it couldn't parse the provided region.
-    my $seqnames_hash = { map { $_ => 1 } @{ $self->seqnames } };
-    
-    if ( not exists $seqnames_hash->{ $chr } ) {
-      # warn("Specified chromosome '$chr' does not exist in file " . $self->{_filename});
-      return undef;
-    } else {
-      die "Unable to get iterator for region '$region' in file ". $self->{_filename} . " -- htslib couldn't parse your region string";
-    }
-  }
-
-  return Bio::DB::HTS::Tabix::Iterator->new( _tabix_iter => $iter, _htsfile => $self->{_htsfile}, _tabix_index => $self->{_tabix_index} );
-}
-
 sub query {
     my ( $self, $region ) = @_;
 
@@ -103,7 +63,7 @@ sub query {
     unless ( defined $chr ) {
         die "You must specify a region in the format chr, chr:start or chr:start-end";
     }
-    
+
     if ( defined $end ) {
         die "End in $region is less than the start" if $end < $start;
     }
@@ -113,7 +73,21 @@ sub query {
         }
     }
 
-    return $self->query_full($chr, $start, $end);
+    my $iter = tbx_query( $self->{_tabix_index}, $region );
+
+    unless ( $iter ) {
+      #this likely means the chromosome wasn't found in the tabix index, or it couldn't parse the provided region.
+      my $seqnames_hash = { map { $_ => 1 } @{ $self->seqnames } };
+      if ( not exists $seqnames_hash->{ $chr } ) {
+        #$self->log->warn("Specified chromosome '$chr' does not exist in file " . $self->_filename);
+      }
+      else {
+        die "Unable to get iterator for region '$region' in file ". $self->{_filename} . " -- htslib couldn't parse your region string";
+        }
+
+    }
+
+    return Bio::DB::HTS::Tabix::Iterator->new( _tabix_iter => $iter, _htsfile => $self->{_htsfile}, _tabix_index => $self->{_tabix_index} );
 }
 
 sub seqnames {
@@ -128,12 +102,8 @@ sub header {
 
 sub header_array {
     my $self = shift;
-    if( $self->{_header} )
-    {
-      my @lines = split(/\n/,$self->{_header});
-      return @lines ;
-    }
-    return ;
+    my @lines = split(/\n/,$self->{_header});
+    return @lines ;
 }
 
 
@@ -141,6 +111,11 @@ sub header_array {
 sub close {
     my $self = shift;
 
+    if ( $self->{_htsfile} ) {
+        Bio::DB::HTSfile::close($self->{_htsfile});
+        delete $self->{_htsfile};
+    }
+
     if ( $self->{_tabix_index} ) {
         tbx_close($self->{_tabix_index});
         delete $self->{_tabix_index};
@@ -205,14 +180,11 @@ Returns all the header lines as a single scalar from the tabixed file
 
 Takes a single region like: '1:4000005-4000009' or '12:5000000'. The coordinate format is 0 or 1-based for start and stop positions depending on how the Tabix index file was created - by default this is 1.
 
-The index for remote files will be downloaded to the system temporary directory by default. Set use_tmp_dir to 0 to download to the current working directory instead.
-
-
 Here are some examples showing Tabix.
 
     use Bio::DB::HTS::Tabix;
 
-    my $tabix = Bio::DB::HTS::Tabix->new(filename => $file, use_tmp_dir => 1);
+    my $tabix = Bio::DB::HTS::Tabix->new(filename => $file);
 
     # Calling region 1
 
